summaryrefslogtreecommitdiffstats
path: root/kdat/BackupDlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/BackupDlg.cpp')
-rw-r--r--kdat/BackupDlg.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdat/BackupDlg.cpp b/kdat/BackupDlg.cpp
index e32f680..c224c0b 100644
--- a/kdat/BackupDlg.cpp
+++ b/kdat/BackupDlg.cpp
@@ -216,7 +216,7 @@ void BackupDlg::show()
_tarParser = new TarParser();
connect( _tarParser, TQT_SIGNAL( sigEntry( const TQString &, int, int, int ) ), this, TQT_SLOT( slotEntry( const TQString &, int, int, int ) ) );
- _proc = new KProcess();
+ _proc = new TDEProcess();
*_proc << Options::instance()->getTarCommand();
if ( _oneFilesystem ) {
*_proc << "-l";
@@ -281,17 +281,17 @@ void BackupDlg::show()
return;
}
- connect( _proc, TQT_SIGNAL( processExited( KProcess* ) ), this, TQT_SLOT( slotProcessExited( KProcess* ) ) );
- connect( _proc, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ), this, TQT_SLOT( slotStdout( KProcess*, char*, int ) ) );
+ connect( _proc, TQT_SIGNAL( processExited( TDEProcess* ) ), this, TQT_SLOT( slotProcessExited( TDEProcess* ) ) );
+ connect( _proc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), this, TQT_SLOT( slotStdout( TDEProcess*, char*, int ) ) );
startTimer( 1000 );
- _proc->start( KProcess::NotifyOnExit, KProcess::Stdout );
+ _proc->start( TDEProcess::NotifyOnExit, TDEProcess::Stdout );
TQDialog::show();
}
-void BackupDlg::slotProcessExited( KProcess* )
+void BackupDlg::slotProcessExited( TDEProcess* )
{
updateStats();
@@ -316,12 +316,12 @@ void BackupDlg::slotProcessExited( KProcess* )
_abort->setEnabled( FALSE );
}
// the KProcess passes the arguments to tar, and tar's output is piped here.
// The output is shown to _tarParser->slotData(), which figures out which files
// are going to tape and their file parameters, and saves these data into
// kdat's archive. The raw data are then written to tape with write().
// 2002-01-27 LEW
-void BackupDlg::slotStdout( KProcess*, char* buf, int len )
+void BackupDlg::slotStdout( TDEProcess*, char* buf, int len )
{
// Don't start throughput timer until the first block of data is written.
if ( _startTime == 0 ) {
@@ -316,12 +316,12 @@ void BackupDlg::slotProcessExited( KProcess* )
_abort->setEnabled( FALSE );
}
-// the KProcess passes the arguments to tar, and tar's output is piped here.
+// the TDEProcess passes the arguments to tar, and tar's output is piped here.
// The output is shown to _tarParser->slotData(), which figures out which files
// are going to tape and their file parameters, and saves these data into